Learn R Programming

hettx (version 1.0.1)

SKS_stat_cov_pool: SKS_stat_cov_pool

Description

SKS_stat_cov_pool is the shifted kolmogorov-smirnov statistic with covariates to increase precision. This is the test statistic used Ding, Feller, and Miratrix (2016), JRSS-B.

SKS_stat_cov is the shifted kolmogorov-smirnov statistic with covariates with model for outcomes calculated on control group only. This avoids "splitting" the treatment variation between tx and co groups. We recommend this method over the "pool" method.

Usage

SKS_stat_cov_pool(Y, Z, X)

SKS_stat_cov(Y, Z, X)

Value

The value of the test.

Arguments

Y

Observed outcome vector

Z

Treatment assigment vector

X

Additional pre-treatment covariates to adjust for in estimation, but not to interact with treatment.

Examples

Run this code
df <- make_randomized_dat( 1000, gamma.vec=c(1,1,1,2), beta.vec=c(-1,-1,1,0) )
SKS_stat_cov_pool(df$Yobs, df$Z, df$A)

df <- make_randomized_dat( 1000, gamma.vec=c(1,1,1,2), beta.vec=c(-1,-1,1,0) )
SKS_stat_cov(df$Yobs, df$Z, df$A)

Run the code above in your browser using DataLab