| get_testing_grid | R Documentation |
Estimates a linear model Y ~ Z + W + Z:W (+X) and samples from
the confidence region of the Z-related coefficients. For each sampled
model, computes individual imputed treatment effects and science tables
of imputed potential outcomes.
get_testing_grid(Y, Z, W, X = NULL, gamma = 1e-04, grid.size = 150)
Y |
Outcome vector. |
Z |
Treatment assignment vector (0/1). |
W |
Covariate matrix for treatment effect interactions. |
X |
Optional covariate matrix for additional adjustment. |
gamma |
Tail probability for the confidence region. Default is 0.0001. |
grid.size |
Number of models to sample. Default is 150. |
A list with components:
grid.size x p matrix, each row a different effect model.
N x grid.size matrix of individual treatment effects.
N x grid.size matrix of imputed control potential outcomes.
N x grid.size matrix of imputed treated potential outcomes.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.