hettx-deprecated: Deprecated functions in hettx

hettx-deprecatedR Documentation

Deprecated functions in hettx

Description

These functions have been renamed to use snake_case. The old dot-case names still work but will emit a deprecation warning. Please update your code to use the new names.

Usage

test.stat.info()

KS.stat(...)

SKS.stat(...)

SKS.stat.cov.pool(...)

SKS.stat.cov(...)

SKS.stat.int.cov.pool(...)

SKS.stat.int.cov(...)

SKS.stat.cov.rq(...)

rq.stat(...)

rq.stat.cond.cov(...)

rq.stat.uncond.cov(...)

WSKS.t(...)

SKS.pool.t(...)

make.linear.data(...)

make.quadradic.data(...)

make.skew.data(...)

make.randomized.dat(...)

make.randomized.compliance.dat(...)

get.p.value(...)

variance.ratio.test(...)

Arguments

...

Arguments passed to the replacement function.


hettx documentation built on Feb. 24, 2026, 5:08 p.m.