make_randomized_compliance_dat: Generate fake data with noncompliance.

View source: R/make_fake_data.R

make_randomized_compliance_datR Documentation

Generate fake data with noncompliance.

Description

This will generate and randomize a science table to get observed outcomes and treatment assignment

Usage

make_randomized_compliance_dat(
  n,
  p = 0.6,
  science.table.generator = make_linear_data,
  include.POs = TRUE,
  ...
)

Arguments

n

Sample size

p

Proportion treated

science.table.generator

Method to generate potential outcomes

include.POs

Preserve potential outcomes in returned value

...

To be passed to science.table.generator

Value

Data frame with data randomized to tx and control, and compliers, etc.

See Also

make_randomized_dat


hettx documentation built on Feb. 24, 2026, 5:08 p.m.