rcrmtvnorm: Generate truncated multivariate normal draws

View source: R/helper_frt.R

rcrmtvnormR Documentation

Generate truncated multivariate normal draws

Description

Draws from a multivariate normal distribution, rejecting any samples outside the confidence region defined by alpha.

Usage

rcrmtvnorm(n, mu, sigma, alpha)

Arguments

n

Number of draws to generate.

mu

Mean vector.

sigma

Covariance matrix.

alpha

Tail probability to exclude (defines the chi-squared confidence region).

Value

An n x K matrix of draws from the truncated distribution.


hettx documentation built on Feb. 24, 2026, 5:08 p.m.