Learn R Programming

hettx (version 1.0.1)

variance_ratio_test: Variance ratio test

Description

Given vector of observed outcomes and treatment vector, test to see if there is evidence the variances are different (taking kurtosis into account).

Usage

variance_ratio_test(Yobs, Z, data = NULL)

Arguments

Yobs

Outcome

Z

Treatment assignment vector

data

Dataframe with variables listed in formula and control.formula

Examples

Run this code
df <- make_randomized_dat( 1000, gamma.vec=c(1,1,1,2), beta.vec=c(-1,-1,1,0) )
variance_ratio_test(df$Yobs, df$Z)

Run the code above in your browser using DataLab