Learn R Programming

hettx (version 1.0.1)

SKS_pool_t: SKS_pool_t

Description

Subtract off group level treatment effect estimates and then look at KS statistic on residuals.

Usage

SKS_pool_t(Y, Z, W)

Arguments

Y

Observed outcome vector

Z

Treatment assigment vector

W

A a factor or categorical covariate.

Details

Distinct from the interacted lm in that the control units are not shifted and centered with respect to eachother.

Examples

Run this code
df <- make_randomized_dat( 1000, gamma.vec=c(1,1,1,2), beta.vec=c(-1,-1,1,0) )
df$W <- sample(c("A", "B", "C"), nrow(df), replace = TRUE)
SKS_pool_t(df$Yobs, df$Z, df$W)

Run the code above in your browser using DataLab