Learn R Programming

hettx (version 1.0.1)

get_testing_grid: Build a grid of treatment effect models for interaction testing

Description

Estimates a linear model Y ~ Z + W + Z:W (+X) and samples from the confidence region of the Z-related coefficients. For each sampled model, computes individual imputed treatment effects and science tables of imputed potential outcomes.

Usage

get_testing_grid(Y, Z, W, X = NULL, gamma = 1e-04, grid.size = 150)

Value

A list with components:

te.grid

grid.size x p matrix, each row a different effect model.

te.mat

N x grid.size matrix of individual treatment effects.

Y0.mat

N x grid.size matrix of imputed control potential outcomes.

Y1.mat

N x grid.size matrix of imputed treated potential outcomes.

Arguments

Y

Outcome vector.

Z

Treatment assignment vector (0/1).

W

Covariate matrix for treatment effect interactions.

X

Optional covariate matrix for additional adjustment.

gamma

Tail probability for the confidence region. Default is 0.0001.

grid.size

Number of models to sample. Default is 150.