Estimates a linear model Y ~ Z + W + Z:W (+X) and samples from
the confidence region of the Z-related coefficients. For each sampled
model, computes individual imputed treatment effects and science tables
of imputed potential outcomes.
get_testing_grid(Y, Z, W, X = NULL, gamma = 1e-04, grid.size = 150)A list with components:
grid.size x p matrix, each row a different effect model.
N x grid.size matrix of individual treatment effects.
N x grid.size matrix of imputed control potential outcomes.
N x grid.size matrix of imputed treated potential outcomes.
Outcome vector.
Treatment assignment vector (0/1).
Covariate matrix for treatment effect interactions.
Optional covariate matrix for additional adjustment.
Tail probability for the confidence region. Default is 0.0001.
Number of models to sample. Default is 150.