| hettx-deprecated | R Documentation |
These functions have been renamed to use snake_case. The old dot-case names still work but will emit a deprecation warning. Please update your code to use the new names.
test.stat.info()
KS.stat(...)
SKS.stat(...)
SKS.stat.cov.pool(...)
SKS.stat.cov(...)
SKS.stat.int.cov.pool(...)
SKS.stat.int.cov(...)
SKS.stat.cov.rq(...)
rq.stat(...)
rq.stat.cond.cov(...)
rq.stat.uncond.cov(...)
WSKS.t(...)
SKS.pool.t(...)
make.linear.data(...)
make.quadradic.data(...)
make.skew.data(...)
make.randomized.dat(...)
make.randomized.compliance.dat(...)
get.p.value(...)
variance.ratio.test(...)
... |
Arguments passed to the replacement function. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.