View source: R/make_fake_data.R
| make_randomized_compliance_dat | R Documentation |
This will generate and randomize a science table to get observed outcomes and treatment assignment
make_randomized_compliance_dat(
n,
p = 0.6,
science.table.generator = make_linear_data,
include.POs = TRUE,
...
)
n |
Sample size |
p |
Proportion treated |
science.table.generator |
Method to generate potential outcomes |
include.POs |
Preserve potential outcomes in returned value |
... |
To be passed to science.table.generator |
Data frame with data randomized to tx and control, and compliers, etc.
make_randomized_dat
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.