Learn R Programming

hettx (version 1.0.1)

make_randomized_compliance_dat: Generate fake data with noncompliance.

Description

This will generate and randomize a science table to get observed outcomes and treatment assignment

Usage

make_randomized_compliance_dat(
  n,
  p = 0.6,
  science.table.generator = make_linear_data,
  include.POs = TRUE,
  ...
)

Value

Data frame with data randomized to tx and control, and compliers, etc.

Arguments

n

Sample size

p

Proportion treated

science.table.generator

Method to generate potential outcomes

include.POs

Preserve potential outcomes in returned value

...

To be passed to science.table.generator

See Also

make_randomized_dat