| rcrmtvnorm | R Documentation |
Draws from a multivariate normal distribution, rejecting any samples outside the confidence region defined by alpha.
rcrmtvnorm(n, mu, sigma, alpha)
n |
Number of draws to generate. |
mu |
Mean vector. |
sigma |
Covariance matrix. |
alpha |
Tail probability to exclude (defines the chi-squared confidence region). |
An n x K matrix of draws from the truncated distribution.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.