Learn R Programming

hettx (version 1.0.1)

rcrmtvnorm: Generate truncated multivariate normal draws

Description

Draws from a multivariate normal distribution, rejecting any samples outside the confidence region defined by alpha.

Usage

rcrmtvnorm(n, mu, sigma, alpha)

Value

An n x K matrix of draws from the truncated distribution.

Arguments

n

Number of draws to generate.

mu

Mean vector.

sigma

Covariance matrix.

alpha

Tail probability to exclude (defines the chi-squared confidence region).